@@ -12,10 +12,10 @@ File timetable_defs.h
 
 /***************************************************************************
  *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   This program is free software: you can redistribute it and/or modify  *
+ *   it under the terms of the GNU Affero General Public License as        *
+ *   published by the Free Software Foundation, either version 3 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  ***************************************************************************/
 
@@ -73,6 +73,7 @@ extern bool SHOW_SUBGROUPS_IN_ACTIVITY_PLANNING;
 
 extern bool WRITE_TIMETABLE_CONFLICTS;
 
+extern bool WRITE_TIMETABLES_STATISTICS;
 extern bool WRITE_TIMETABLES_XML;
 extern bool WRITE_TIMETABLES_DAYS_HORIZONTAL;
 extern bool WRITE_TIMETABLES_DAYS_VERTICAL;
@@ -90,11 +91,15 @@ extern bool WRITE_TIMETABLES_ACTIVITIES;
 
 extern bool SHOW_SHORTCUTS_ON_MAIN_WINDOW;
 
+extern bool SHOW_TOOLTIPS_FOR_CONSTRAINTS_WITH_TABLES;
+
 extern bool ENABLE_ACTIVITY_TAG_MAX_HOURS_DAILY;
 extern bool ENABLE_STUDENTS_MAX_GAPS_PER_DAY;
 
 extern bool SHOW_WARNING_FOR_NOT_PERFECT_CONSTRAINTS;
 
+extern bool SHOW_WARNING_FOR_SUBGROUPS_WITH_THE_SAME_ACTIVITIES;
+
 extern bool ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS;
 extern bool SHOW_WARNING_FOR_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS;
 
