@@ -8,61 +8,68 @@
 
 /***************************************************************************
  *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   This program is free software: you can redistribute it and/or modify  *
+ *   it under the terms of the GNU Affero General Public License as        *
+ *   published by the Free Software Foundation, either version 3 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  ***************************************************************************/
 
 #ifndef ADDACTIVITYFORM_H
 #define ADDACTIVITYFORM_H
 
-#include "addactivityform_template.h"
+#include "ui_addactivityform_template.h"
 
 #include "timetable_defs.h"
 #include "timetable.h"
 #include "fet.h"
 
-//#include "fetmainform.h"
+#include <QSet>
+//#include <QHash>
+#include <QList>
 
-#include <q3combobox.h>
-#include <qmessagebox.h>
-#include <q3groupbox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
+class AddActivityForm : public QDialog, Ui::AddActivityForm_template  {
+	Q_OBJECT
+	
+private:
+	QList<QSpinBox*> durList;
+	QList<QCheckBox*> activList;
 
+	QSpinBox* dur(int i);
+	QCheckBox* activ(int i);
+	
+	QSet<QString> teacherNamesSet;
+	QSet<QString> subjectNamesSet;
+	QSet<QString> activityTagNamesSet;
+	//QHash<QString, int> numberOfStudentsHash;
 
-class AddActivityForm : public AddActivityForm_template  {
-public: 
-	AddActivityForm();
+public:
+	QList<QString> canonicalStudentsSetsNames;
+
+	AddActivityForm(QWidget* parent, const QString& teacherName, const QString& studentsSetName, const QString& subjectName, const QString& activityTagName);
 	~AddActivityForm();
 
-	void updateStudentsListBox();
-	void updateTeachersListBox();
+	void updateStudentsListWidget();
+	void updateTeachersListWidget();
 	void updateSubjectsComboBox();
-	void updateSubjectTagsComboBox();
+	void updateActivityTagsListWidget();
 	void updatePreferredDaysComboBox();
 	void updatePreferredHoursComboBox();
 
+public slots:
 	void addTeacher();
 	void removeTeacher();
 	void addStudents();
 	void removeStudents();
-	void subjectChanged(const QString& dummy);
-	void subjectTagChanged(const QString& dummy);
-	void hourChanged();
-	void dayChanged();
-	void parityChanged();
-	void durationChanged();
-	void activityChanged();
+
+	void addActivityTag();
+	void removeActivityTag();
+
 	void splitChanged();
 	
 	void clearTeachers();
 	void clearStudents();
+	void clearActivityTags();
 	
 	void showYearsChanged();
 	void showGroupsChanged();
@@ -70,6 +77,22 @@ public:
 
 	void addActivity();
 	void help();
+	
+	void minDaysChanged();
+};
+
+class SecondMinDaysDialog: public QDialog
+{
+	Q_OBJECT
+public:
+	SecondMinDaysDialog(QWidget* p, int minD, double weight);
+	~SecondMinDaysDialog();
+	
+	double weight;
+	QLineEdit* percText;
+
+public slots:
+	void yesPressed();
 };
 
 #endif
