@@ -8,46 +8,44 @@
 
 /***************************************************************************
  *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   This program is free software: you can redistribute it and/or modify  *
+ *   it under the terms of the GNU Affero General Public License as        *
+ *   published by the Free Software Foundation, either version 3 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  ***************************************************************************/
 
 #ifndef ADDCONSTRAINTACTIVITIESNOTOVERLAPPINGFORM_H
 #define ADDCONSTRAINTACTIVITIESNOTOVERLAPPINGFORM_H
 
-#include "addconstraintactivitiesnotoverlappingform_template.h"
+#include "ui_addconstraintactivitiesnotoverlappingform_template.h"
 #include "timetable_defs.h"
 #include "timetable.h"
 #include "fet.h"
-//#include "fetmainform.h"
-
-#include <q3combobox.h>
-#include <q3listbox.h>
-#include <qmessagebox.h>
-#include <q3groupbox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
 
 #include <QList>
 
-class AddConstraintActivitiesNotOverlappingForm : public AddConstraintActivitiesNotOverlappingForm_template  {
+class AddConstraintActivitiesNotOverlappingForm : public QDialog, Ui::AddConstraintActivitiesNotOverlappingForm_template  {
+	Q_OBJECT
 public:
-	AddConstraintActivitiesNotOverlappingForm();
+	AddConstraintActivitiesNotOverlappingForm(QWidget* parent);
 	~AddConstraintActivitiesNotOverlappingForm();
 
-	void updateActivitiesListBox();
+	void updateActivitiesListWidget();
 	
+	bool filterOk(Activity* a);
+
+public slots:
 	void addActivity();
+	void addAllActivities();
 	void removeActivity();
 
 	void addConstraint();
 	
+	void filterChanged();
+	
+	void clear();
+	
 private:
 	//the id's of the activities listed in the activities list
 	QList<int> activitiesList;
