@@ -8,10 +8,10 @@
 //
 /***************************************************************************
  *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   This program is free software: you can redistribute it and/or modify  *
+ *   it under the terms of the GNU Affero General Public License as        *
+ *   published by the Free Software Foundation, either version 3 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  ***************************************************************************/
 
@@ -158,10 +158,12 @@ public slots:
 	void showSubgroupsInComboBoxesToggled(bool checked);
 	void showSubgroupsInActivityPlanningToggled(bool checked);
 	void on_settingsShowShortcutsOnMainWindowAction_toggled();
+	void on_settingsShowToolTipsForConstraintsWithTablesAction_toggled();
 	
 	///write timetables options
 	void on_enableConflictsTimetableAction_toggled();
 
+	void on_enableStatisticsTimetablesAction_toggled();
 	void on_enableXmlTimetablesAction_toggled();
 	void on_enableDaysHorizontalTimetablesAction_toggled();
 	void on_enableDaysVerticalTimetablesAction_toggled();
@@ -184,6 +186,8 @@ public slots:
 	void on_settingsConfirmRemoveRedundantAction_toggled();
 	void on_settingsConfirmSaveTimetableAction_toggled();
 	//////
+
+	void showWarningForSubgroupsWithTheSameActivitiesToggled(bool checked);
 	
 	void enableActivityTagMaxHoursDailyToggled(bool checked);
 	void enableStudentsMaxGapsPerDayToggled(bool checked);
