@@ -8,23 +8,27 @@
 
 /***************************************************************************
  *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   This program is free software: you can redistribute it and/or modify  *
+ *   it under the terms of the GNU Affero General Public License as        *
+ *   published by the Free Software Foundation, either version 3 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  ***************************************************************************/
 
 #ifndef HELPFAQFORM_H
 #define HELPFAQFORM_H
 
-#include "helpfaqform_template.h"
+#include "ui_helpfaqform_template.h"
 
-class HelpFaqForm : public HelpFaqForm_template
+class HelpFaqForm : public QDialog, public Ui::HelpFaqForm_template
 {
-public: 
-	HelpFaqForm();
+	Q_OBJECT
+	
+public:
+	HelpFaqForm(QWidget* parent);
 	~HelpFaqForm();
+	
+	void setText();
 };
 
 #endif
