@@ -8,72 +8,82 @@
 
 /***************************************************************************
  *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   This program is free software: you can redistribute it and/or modify  *
+ *   it under the terms of the GNU Affero General Public License as        *
+ *   published by the Free Software Foundation, either version 3 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  ***************************************************************************/
 
 #ifndef MODIFYACTIVITYFORM_H
 #define MODIFYACTIVITYFORM_H
 
-#include "modifyactivityform_template.h"
+#include "ui_modifyactivityform_template.h"
 
 #include "timetable_defs.h"
 #include "timetable.h"
 #include "fet.h"
 
-//#include "fetmainform.h"
+#include <QSet>
+//#include <QHash>
+#include <QList>
 
-#include <q3combobox.h>
-#include <qmessagebox.h>
-#include <q3groupbox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
-#include <q3listbox.h>
+class ModifyActivityForm : public QDialog, Ui::ModifyActivityForm_template  {
+	Q_OBJECT
 
+private:
+	QList<QSpinBox*> durList;
+	QList<QCheckBox*> activList;
+
+	QSpinBox* dur(int i);
+	QCheckBox* activ(int i);
+
+	QSet<QString> teacherNamesSet;
+	QSet<QString> subjectNamesSet;
+	QSet<QString> activityTagNamesSet;
+	//QHash<QString, int> numberOfStudentsHash;
 
-class ModifyActivityForm : public ModifyActivityForm_template  {
 public:
+	QList<QString> canonicalStudentsSetsNames;
+
 	int _id;
 	int _activityGroupId;
 	Activity* _activity;
 	QStringList _teachers;
 	QString _subject;
-	QString _subjectTag;
+	QStringList _activityTags;
 	QStringList _students;
 
-	ModifyActivityForm(int id, int activityGroupId);
+	ModifyActivityForm(QWidget* parent, int id, int activityGroupId);
 	~ModifyActivityForm();
 
+	void updateStudentsListWidget();
+	void updateTeachersListWidget();
+	void updateSubjectsComboBox();
+	void updateActivityTagsListWidget();
+	
+public slots:
+	void ok();
+	void cancel();
+
 	void addTeacher();
 	void removeTeacher();
+
 	void addStudents();
 	void removeStudents();
-	void updateStudentsListBox();
-	void updateTeachersListBox();
-	void updateSubjectsComboBox();
-	void updateSubjectTagsComboBox();
-	
+
 	void clearTeachers();
 	void clearStudents();
+	void clearActivityTags();
+
+	void addActivityTag();
+	void removeActivityTag();
 
-	void subjectChanged(const QString& dummy);
-	void subjectTagChanged(const QString& dummy);
-	//void parityChanged();
-	void durationChanged();
-	void activityChanged();
-	
 	void showYearsChanged();
 	void showGroupsChanged();
 	void showSubgroupsChanged();
-
-	void ok();
-	void cancel();
+	
+	void help();
 };
 
 #endif
