@@ -8,10 +8,10 @@
 //
 /***************************************************************************
  *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   This program is free software: you can redistribute it and/or modify  *
+ *   it under the terms of the GNU Affero General Public License as        *
+ *   published by the Free Software Foundation, either version 3 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  ***************************************************************************/
 
@@ -44,8 +44,10 @@ RemoveRedundantForm::RemoveRedundantForm(QWidget* parent): QDialog(parent)
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
 	
-	connect(buttonBox, SIGNAL(accepted()), this, SLOT(wasAccepted()));
-	connect(buttonBox, SIGNAL(rejected()), this, SLOT(wasCanceled()));
+	okPushButton->setDefault(true);
+	
+	connect(okPushButton, SIGNAL(clicked()), this, SLOT(wasAccepted()));
+	connect(cancelPushButton, SIGNAL(clicked()), this, SLOT(wasCanceled()));
 }
 
 RemoveRedundantForm::~RemoveRedundantForm()
