@@ -8,10 +8,10 @@
 
 /***************************************************************************
  *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   This program is free software: you can redistribute it and/or modify  *
+ *   it under the terms of the GNU Affero General Public License as        *
+ *   published by the Free Software Foundation, either version 3 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  ***************************************************************************/
 
@@ -458,12 +458,15 @@ again_here_1:
 	QHash<QString, StudentsGroup*> groupsHash;
 	
 	StudentsYear* yearPointer=NULL;
-	foreach(StudentsYear* y, gt.rules.yearsList)
-		if(y->name==year){
-			yearPointer=y;
+	int yearIndex=-1;
+	for(int i=0; i<gt.rules.yearsList.count(); i++)
+		if(gt.rules.yearsList[i]->name==year){
+			yearPointer=gt.rules.yearsList[i];
+			yearIndex=i;
 			break;
 		}
 	assert(yearPointer!=NULL);
+	assert(yearIndex>=0);
 	
 	QSet<QString> notExistingGroupsSet;
 	QSet<QString> notExistingSubgroupsSet;
@@ -614,11 +617,9 @@ again_here_2:
 		}
 	}
 	
-	for(int i=0; i<gt.rules.yearsList.count(); i++)
-		if(gt.rules.yearsList[i]==yearPointer){
-			gt.rules.yearsList[i]=newYear;
-			break;
-		}
+	assert(yearIndex>=0 && yearIndex<gt.rules.yearsList.count());
+	assert(gt.rules.yearsList[yearIndex]==yearPointer);
+	gt.rules.yearsList[yearIndex]=newYear;
 	
 	QString s=QString("");
 	
@@ -627,6 +628,7 @@ again_here_2:
 	int nSpaceConstraintsBefore=gt.rules.spaceConstraintsList.count();
 	int nGroupActivitiesInInitialOrderItemsBefore=gt.rules.groupActivitiesInInitialOrderList.count();
 	
+	gt.rules.computePermanentStudentsHash();
 	gt.rules.removeYearPointerAfterSplit(yearPointer);
 
 	int nActivitiesAfter=gt.rules.activitiesList.count();
@@ -712,7 +714,7 @@ void SplitYearForm::help()
 		
 	s+="\n\n";
 	
-	s+=tr("When dividing again a year, you might get a warning about subgroups which will be removed. If you didn't explicitely use"
+	s+=tr("When dividing again a year, you might get a warning about subgroups which will be removed. If you didn't explicitly use"
 		" (these) subgroups in your activities or constraints, probably you can safely ignore this warning. Generally, if you use years' division"
 		" by categories, it is groups that matter.");
 	
@@ -722,7 +724,7 @@ void SplitYearForm::help()
 	
 	s+="\n\n";
 	
-	s+=tr("If you have many subgroups and you don't explicitely use them, it is recommended to use the three global settings: hide subgroups"
+	s+=tr("If you have many subgroups and you don't explicitly use them, it is recommended to use the three global settings: hide subgroups"
 		" in combo boxes, hide subgroups in activity planning, and do not write subgroups timetables on hard disk.");
 	s+="\n";
 	s+=tr("Note that if you are only working to get a feasible timetable, without the need to obtain the students timetable (XML or HTML) on"
@@ -744,6 +746,11 @@ void SplitYearForm::help()
 	s+=tr("Maybe an alternative to dividing a year into many categories/subgroups would be to enter individual students as FET subgroups and add into"
 		" each group the corresponding subgroups. But this is hard to do from the FET interface - maybe a solution would be to use an automatic"
 		" tool to convert your instition data into a file in .fet format.");
+	s+=" ";
+	s+=tr("Or you might use the FET feature to import students sets from comma separated values (CSV) files.");
+	s+=" ";
+	s+=tr("In such cases (individual students as FET subgroups), remember that a smaller number of total subgroups means faster generation time, so"
+		" you might want to consider a single subgroup for two or more students who have the exact same activities and constraints.");
 	
 	//show the message in a dialog
 	QDialog dialog(this);
