@@ -56,6 +56,11 @@
 #include <QObject>
 #include <QMetaObject>
 
+//begin by Marco Vassura
+#include <QBrush>
+#include <QColor>
+//end by Marco Vassura
+
 extern const QString COMPANY;
 extern const QString PROGRAM;
 
@@ -263,9 +268,17 @@ void TimetableViewTeachersForm::updateTeachersTimetableTable(){
 	teacherNameTextLabel->setText(s);
 
 	assert(gt.rules.initialized);
-
+	
 	for(int j=0; j<gt.rules.nHoursPerDay && j<teachersTimetableTable->rowCount(); j++){
 		for(int k=0; k<gt.rules.nDaysPerWeek && k<teachersTimetableTable->columnCount(); k++){
+			//begin by Marco Vassura
+			// add colors (start)
+			//if(USE_GUI_COLORS) {
+				teachersTimetableTable->item(j, k)->setBackground(teachersTimetableTable->palette().color(QPalette::Base));
+				teachersTimetableTable->item(j, k)->setForeground(teachersTimetableTable->palette().color(QPalette::Text));
+			//}
+			// add colors (end)
+			//end by Marco Vassura
 			s = "";
 			int ai=teachers_timetable_weekly[teacher][k][j]; //activity index
 			//Activity* act=gt.rules.activitiesList.at(ai);
@@ -300,7 +313,7 @@ void TimetableViewTeachersForm::updateTeachersTimetableTable(){
 					s+="\n";
 					s+=act->studentsNames.join(", ");
 				}
-
+				
 				int r=best_solution.rooms[ai];
 				if(r!=UNALLOCATED_SPACE && r!=UNSPECIFIED_ROOM){
 					//s+=" ";
@@ -340,6 +353,20 @@ void TimetableViewTeachersForm::updateTeachersTimetableTable(){
 				}
 				s+=descr;
 				//added by Volker Dirr (end)
+				
+				//begin by Marco Vassura
+				// add colors (start)
+				if(USE_GUI_COLORS /*&& act->studentsNames.count()>0*/){
+					QBrush bg(stringToColor(act->subjectName+" "+act->studentsNames.join(", ")));
+					teachersTimetableTable->item(j, k)->setBackground(bg);
+					double brightness = bg.color().redF()*0.299 + bg.color().greenF()*0.587 + bg.color().blueF()*0.114;
+					if (brightness<0.5)
+						teachersTimetableTable->item(j, k)->setForeground(QBrush(Qt::white));
+					else
+						teachersTimetableTable->item(j, k)->setForeground(QBrush(Qt::black));
+				}
+				// add colors (end)
+				//end by Marco Vassura
 			}
 			else{
 				if(teacherNotAvailableDayHour[teacher][k][j] && PRINT_NOT_AVAILABLE_TIME_SLOTS)
@@ -367,6 +394,26 @@ void TimetableViewTeachersForm::resizeEvent(QResizeEvent* event)
 	teachersTimetableTable->resizeRowsToContents();
 }
 
+//begin by Marco Vassura
+QColor TimetableViewTeachersForm::stringToColor(QString s)
+{
+	// CRC-24 Based on RFC 2440 Section 6.1
+	unsigned long crc = 0xB704CEL;
+	int i;
+	QChar *data = s.data();
+	while (!data->isNull()) {
+		crc ^= (data->unicode() & 0xFF) << 16;
+		for (i = 0; i < 8; i++) {
+			crc <<= 1;
+			if (crc & 0x1000000)
+				crc ^= 0x1864CFBL;
+		}
+		data++;
+	}
+	return QColor::fromRgb((int)(crc>>16), (int)((crc>>8) & 0xFF), (int)(crc & 0xFF));
+}
+//end by Marco Vassura
+
 void TimetableViewTeachersForm::currentItemChanged(QTableWidgetItem* current, QTableWidgetItem* previous)
 {
 	Q_UNUSED(previous);
